==> tine20-allinone_2019.12.5.tar.bz2: Setup/js/Setup-lang-cs-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: cs\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Backend"
: "Backend"

, "Standard IMAP"
: "Standardní IMAP"

, "Standard SMTP"
: "Standardní SMTP"

, "Imap"
: "IMAP"

, "Hostname"
: "Název nebo adresa počítače"

, "Username"
: "Uživatelské jméno"

, "Password"
: "Heslo"

, "Port"
: "Port"

, "Secure Connection"
: "Zabezpečení připojení"

, "None"
: "Žádné"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Použít systémový účet"

, "No"
: "Ne"

, "Yes"
: "Ano"

, "Append domain to login name"
: "Připojit doménu k přihlašovacímu jménu"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: "SMTP"

, "Authentication"
: "Autentikace"

, "Login"
: "Přihlášení"

, "Plain"
: "Prosté"

, "Primary Domain"
: "Primární doména"

, "Secondary Domains (comma separated)"
: "Sekundární domény (oddělené čárkou)"

, "Notifications service address"
: "Adresa služby pro zasílání upozornění"

, "Notification Username"
: "Uživatelské jméno pro upozornění"

, "Notification Password"
: "Heslo pro upozornění"

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: ""

, "MySql Hostname"
: "Adresa MySQL serveru"

, "MySql Database"
: "Název MySQL databáze"

, "MySql User"
: "Uživatel MySQL"

, "MySql Password"
: "Heslo k MySQL databázi"

, "MySql Port"
: "Port MySQL"

, "User or UID"
: ""

, "Group or GID"
: ""

, "Home Template"
: ""

, "Password Scheme"
: ""

, "PLAIN-MD5"
: ""

, "MD5-CRYPT"
: ""

, "SHA1"
: ""

, "SHA256"
: ""

, "SSHA256"
: ""

, "SHA512"
: ""

, "SSHA512"
: ""

, "PLAIN"
: ""

, "I have read the license agreement and accept it"
: "Přečetl(a) jsem si licenční ujednání a souhlasím"

, "License Agreement"
: "Licenční ujednání"

, "I have read the privacy agreement and accept it"
: "Přečetl(a) jsem si ujednání o ochraně soukromí a souhlasím"

, "Privacy Agreement"
: "Ujednání o ochraně soukromí"

, "Accept Terms and Conditions"
: "Přijmout podmínky"

, "Performing Environment Checks..."
: "Provádím test prostředí"

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: "Kontrola"

, "Result"
: "Výsledek"

, "Error"
: "Chyba"

, "Run setup tests"
: "Spustit instalační testy"

, "Ignore setup tests"
: "Ignorovat instalační testy"

, "Install application"
: "Instalovat aplikaci"

, "File"
: ""

, "Setup Authentication"
: "Přihlášení do instalačního programu"

, "Database"
: "Databáze"

, "User"
: "Uživatel"

, "Prefix"
: "Prefix"

, "Logging"
: "Logování"

, "Filename"
: "Název souboru"

, "Priority"
: "Priorita"

, "Caching"
: "Kešování"

, "Lifetime (seconds)"
: "Životnost (v sekundách)"

, "Path"
: "Cesta"

, "Queue"
: ""

, "Session"
: ""

, "Temporary files"
: "Dočasné soubory"

, "Temporary Files Path"
: "Cesta pro dočasné soubory"

, "Filestore directory"
: ""

, "Filestore Path"
: ""

, "Addressbook Map panel"
: "Mapový panel v Adresáři"

, "Map panel"
: "Mapový panel"

, "disabled"
: "zakázáno"

, "enabled"
: "povoleno"

, "Config file is not writable"
: "Do konfiguračního souboru nelze zapisovat"

, "Save config"
: "Uložit konfiguraci"

, "Download config file"
: "Stáhnout konfigurační soubor"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Terms and Conditions"
: "Podmínky a ujednání"

, "Setup Checks"
: "Instalační kontroly"

, "Config Manager"
: "Správce konfigurace"

, "Authentication/Accounts"
: "Autentikace/Účty"

, "Email"
: "Email"

, "Application Manager"
: "Správce aplikací"

, "Delete all existing users and groups"
: "Smazat všechny stávající uživatele a skupiny"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Přechod z SQL na LDAP smaže všechny stávající uživatelské účty, skupiny a role. Opravdu chcete změnit backend pro uložení účtů na LDAP?"

, "TLS client certificate"
: ""

, "Initial Admin User"
: ""

, "Initial admin login name"
: "Počáteční přihlašovací jméno administrátora"

, "Initial admin Password"
: "Počáteční heslo administrátora"

, "Password confirmation"
: "Potvrzení hesla"

, "Authentication provider"
: "Poskytovatel autentikace"

, "Try to split username"
: "Zkusit rozdělit uživatelské jméno"

, "Account canonical form"
: "Kanonická forma účtu"

, "Account domain name"
: ""

, "Account domain short name"
: "Krátký název domény"

, "Host"
: "Server"

, "Login name"
: "Přihlašovací jméno"

, "Bind requires DN"
: "Připojení vyžaduje DN"

, "Start TLS"
: ""

, "Base DN"
: "Základní DN"

, "Search filter"
: "Vyhledávací filtr"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Uložení účtů"

, "Default user group name"
: "Jméno výchozí skupiny pro uživatele"

, "Default admin group name"
: "Jméno výchozí skupiny pro administrátory"

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: ""

, "User can change password"
: "Uživatel si může měnit heslo"

, "Enable password policy"
: ""

, "Only ASCII"
: ""

, "Minimum length"
: ""

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: ""

, "Minimum special chars"
: ""

, "Minimum numbers"
: ""

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: "Nastavení přesměrování"

, "Redirect Url (redirect to login screen if empty)"
: "URL pro přesměrování (ponecháte-li prázdné, přesměrovat na přihlašovací obrazovku)"

, "Redirect Always (if No, only redirect after logout)"
: "Vždy přesměrovat (pokud Ne, přesměrovat jen při odhlášení)"

, "Redirect to referring site, if exists"
: "Přesměrovat na odkazovaný web, pokud existuje"

, "Password encoding"
: "Kódování hesla"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "DN uživatele"

, "User Filter"
: "Filtr uživatelů"

, "User Search Scope"
: "Oblast hledání uživatelů"

, "Groups DN"
: "DN pro skupiny"

, "Group Filter"
: "Filtr skupin"

, "Group Search Scope"
: "Oblast hledání skupin"

, "Use Rfc 2307 bis"
: "Používat Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Minimální Id uživatele"

, "Max User Id"
: "Maximální Id uživatele"

, "Min Group Id"
: "Minimální Id skupiny"

, "Max Group Id"
: "Maximální Id skupiny"

, "Group UUID Attribute name"
: "Název atributu pro UUID skupiny"

, "User UUID Attribute name"
: "Název atributu pro UUID uživatele"

, "Readonly access"
: ""

, "Save config and install"
: "Uložit konfiguraci a instalovat"

, "Passwords don't match"
: "Hesla se neshodují"

, "Should not be empty"
: "Nemělo by být prázdné"

, "Setup"
: ""

, "Application, Applications"
: [
  "Aplikace"
 ,"Aplikace"
 ,"Aplikací"
 ,"Aplikací"

]
, "Name"
: "Název"

, "Enabled"
: "Povoleno"

, "Order"
: "Pořadí"

, "Installed Version"
: "Nainstalovaná verze"

, "Available Version"
: "Dostupná verze"

, "Status"
: "Stav"

, "Depends on"
: "Závisí na"

, "Uninstall application"
: "Odinstalovat aplikaci"

, "Update application"
: "Aktualizovat aplikaci"

, "Go to {0} login"
: "Jít na příhlášení do {0}"

, "uninstall"
: "odinstalovat"

, "Do you really want to uninstall the application(s)?"
: "Opravdu chcete aplikaci/e odinstalovat?"

, "This may take a while"
: "Tato operace může chvíli trvat"

, "Dependency Violation"
: "Porušení závislosti"

, "CLI Required"
: ""

, "Application"
: "Aplikace"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Setup/js/Setup-lang-cs-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Czech (http://www.transifex.com/tine20/tine20/language/cs/)\nLanguage: cs\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: "Přečetl(a) jsem si licenční ujednání a souhlasím"

, "License Agreement"
: "Licenční ujednání"

, "I have read the privacy agreement and accept it"
: "Přečetl(a) jsem si ujednání o ochraně soukromí a souhlasím"

, "Privacy Agreement"
: "Ujednání o ochraně soukromí"

, "Accept Terms and Conditions"
: "Přijmout podmínky"

, "Backend"
: "Backend"

, "Standard IMAP"
: "Standardní IMAP"

, "Standard SMTP"
: "Standardní SMTP"

, "Imap"
: "IMAP"

, "Hostname"
: "Název nebo adresa počítače"

, "Username"
: "Uživatelské jméno"

, "Password"
: "Heslo"

, "Port"
: "Port"

, "Secure Connection"
: "Zabezpečení připojení"

, "None"
: "Žádné"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Použít systémový účet"

, "No"
: "Ne"

, "Yes"
: "Ano"

, "Append domain to login name"
: "Připojit doménu k přihlašovacímu jménu"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: ""

, "Cyrus Admin Password"
: ""

, "Use proxy auth"
: ""

, "Smtp"
: "SMTP"

, "Authentication"
: "Autentikace"

, "Login"
: "Přihlášení"

, "Plain"
: "Prosté"

, "Primary Domain"
: "Primární doména"

, "Secondary Domains (comma separated)"
: "Sekundární domény (oddělené čárkou)"

, "Notifications service address"
: "Adresa služby pro zasílání upozornění"

, "Notification Username"
: "Uživatelské jméno pro upozornění"

, "Notification Password"
: "Heslo pro upozornění"

, "Notifications local client (hostname or IP address)"
: ""

, "SIEVE"
: ""

, "MySql Hostname"
: "Adresa MySQL serveru"

, "MySql Database"
: "Název MySQL databáze"

, "MySql User"
: "Uživatel MySQL"

, "MySql Password"
: "Heslo k MySQL databázi"

, "MySql Port"
: "Port MySQL"

, "User or UID"
: ""

, "Group or GID"
: ""

, "Home Template"
: ""

, "Password Scheme"
: ""

, "PLAIN-MD5"
: ""

, "MD5-CRYPT"
: ""

, "SHA1"
: ""

, "SHA256"
: ""

, "SSHA256"
: ""

, "SHA512"
: ""

, "SSHA512"
: ""

, "PLAIN"
: ""

, "Terms and Conditions"
: "Podmínky a ujednání"

, "Setup Checks"
: "Instalační kontroly"

, "Config Manager"
: "Správce konfigurace"

, "Authentication/Accounts"
: "Autentikace/Účty"

, "Email"
: "Email"

, "Application Manager"
: "Správce aplikací"

, "Setup"
: ""

, "Name"
: "Název"

, "Enabled"
: "Povoleno"

, "Order"
: "Pořadí"

, "Installed Version"
: "Nainstalovaná verze"

, "Available Version"
: "Dostupná verze"

, "Status"
: "Stav"

, "Depends on"
: "Závisí na"

, "Install application"
: "Instalovat aplikaci"

, "Uninstall application"
: "Odinstalovat aplikaci"

, "Update application"
: "Aktualizovat aplikaci"

, "Go to {0} login"
: "Jít na příhlášení do {0}"

, "uninstall"
: "odinstalovat"

, "Do you really want to uninstall the application(s)?"
: "Opravdu chcete aplikaci/e odinstalovat?"

, "This may take a while"
: "Tato operace může chvíli trvat"

, "Dependency Violation"
: "Porušení závislosti"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Smazat všechny stávající uživatele a skupiny"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Přechod z SQL na LDAP smaže všechny stávající uživatelské účty, skupiny a role. Opravdu chcete změnit backend pro uložení účtů na LDAP?"

, "TLS client certificate"
: ""

, "Initial Admin User"
: ""

, "Initial admin login name"
: "Počáteční přihlašovací jméno administrátora"

, "Initial admin Password"
: "Počáteční heslo administrátora"

, "Password confirmation"
: "Potvrzení hesla"

, "Authentication provider"
: "Poskytovatel autentikace"

, "Try to split username"
: "Zkusit rozdělit uživatelské jméno"

, "Account canonical form"
: "Kanonická forma účtu"

, "Account domain name"
: ""

, "Account domain short name"
: "Krátký název domény"

, "Host"
: "Server"

, "Login name"
: "Přihlašovací jméno"

, "Bind requires DN"
: "Připojení vyžaduje DN"

, "Start TLS"
: ""

, "Base DN"
: "Základní DN"

, "Search filter"
: "Vyhledávací filtr"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Uložení účtů"

, "Default user group name"
: "Jméno výchozí skupiny pro uživatele"

, "Default admin group name"
: "Jméno výchozí skupiny pro administrátory"

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: ""

, "User can change password"
: "Uživatel si může měnit heslo"

, "Enable password policy"
: ""

, "Only ASCII"
: ""

, "Minimum length"
: ""

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: ""

, "Minimum special chars"
: ""

, "Minimum numbers"
: ""

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: "Nastavení přesměrování"

, "Redirect Url (redirect to login screen if empty)"
: "URL pro přesměrování (ponecháte-li prázdné, přesměrovat na přihlašovací obrazovku)"

, "Redirect Always (if No, only redirect after logout)"
: "Vždy přesměrovat (pokud Ne, přesměrovat jen při odhlášení)"

, "Redirect to referring site, if exists"
: "Přesměrovat na odkazovaný web, pokud existuje"

, "Password encoding"
: "Kódování hesla"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "DN uživatele"

, "User Filter"
: "Filtr uživatelů"

, "User Search Scope"
: "Oblast hledání uživatelů"

, "Groups DN"
: "DN pro skupiny"

, "Group Filter"
: "Filtr skupin"

, "Group Search Scope"
: "Oblast hledání skupin"

, "Use Rfc 2307 bis"
: "Používat Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "Minimální Id uživatele"

, "Max User Id"
: "Maximální Id uživatele"

, "Min Group Id"
: "Minimální Id skupiny"

, "Max Group Id"
: "Maximální Id skupiny"

, "Group UUID Attribute name"
: "Název atributu pro UUID skupiny"

, "User UUID Attribute name"
: "Název atributu pro UUID uživatele"

, "Readonly access"
: ""

, "Save config and install"
: "Uložit konfiguraci a instalovat"

, "Save config"
: "Uložit konfiguraci"

, "Passwords don't match"
: "Hesla se neshodují"

, "Should not be empty"
: "Nemělo by být prázdné"

, "Performing Environment Checks..."
: "Provádím test prostředí"

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: "Kontrola"

, "Result"
: "Výsledek"

, "Error"
: "Chyba"

, "Run setup tests"
: "Spustit instalační testy"

, "Ignore setup tests"
: "Ignorovat instalační testy"

, "Application, Applications"
: [
  "Aplikace"
 ,"Aplikace"
 ,"Aplikací"
 ,"Aplikací"

]
, "File"
: ""

, "Setup Authentication"
: "Přihlášení do instalačního programu"

, "Database"
: "Databáze"

, "User"
: "Uživatel"

, "Prefix"
: "Prefix"

, "Logging"
: "Logování"

, "Filename"
: "Název souboru"

, "Priority"
: "Priorita"

, "Caching"
: "Kešování"

, "Lifetime (seconds)"
: "Životnost (v sekundách)"

, "Path"
: "Cesta"

, "Queue"
: ""

, "Session"
: ""

, "Temporary files"
: "Dočasné soubory"

, "Temporary Files Path"
: "Cesta pro dočasné soubory"

, "Filestore directory"
: ""

, "Filestore Path"
: ""

, "Addressbook Map panel"
: "Mapový panel v Adresáři"

, "Map panel"
: "Mapový panel"

, "disabled"
: "zakázáno"

, "enabled"
: "povoleno"

, "Config file is not writable"
: "Do konfiguračního souboru nelze zapisovat"

, "Download config file"
: "Stáhnout konfigurační soubor"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "Aplikace"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
